@@ -1,3 +1,57 @@
+day_html_header = """<html lang="zh-cn">
+<header>
+    <meta charset="utf-8">
+    <style type="text/css">
+        table {
+            border-spacing: 0;
+            align-items: center;
+            border: 1px solid #000000;
+            margin: auto;
+        }
+        td {
+            text-align: center;
+        }
+        caption{
+            font-size: large;
+            color: #0d7eff;
+        }
+    </style>
+</header>
+"""
+day_html_body = """<body>
+<table border="1">
+    <caption><b>{caption}</b></caption>
+    <tr>
+        <th width="80px">预计时间</th>
+        <th width="80px">比赛级别</th>
+        <th width="50%" bgcolor=#FAEBD7>对战双方</th>
+    </tr>
+    {body}
+</table>
+</body>
+</html>"""
+
+
+def day_analyze_builder(date: str, inf: dict) -> str:
+    """
+    内部函数，格式化今日比赛信息
+
+    :param date: 日期
+    :param inf: 比赛信息
+    :return:
+    """
+    _msg = ""
+    for tournamentID, matchesINFO in inf["info"].items():
+        _msg += f"""<tr><th colspan="3" align="center">联赛ID:{tournamentID}&nbsp;&nbsp;&nbsp;{matchesINFO['tournamentinfo']['short_name']}</th></tr>"""
+        for match in matchesINFO["list"]:
+            _msg += f"""<tr><td>{match['start_time']}</td><td>{match['round_name']}</td><td> {match['team_a_short_name']} <font color=red>VS</font> {match['team_b_short_name']}</td></tr>"""
+    return day_html_header + day_html_body.format(caption=f"---{date}---", body=_msg)
+
+
+class DayAnalyze:
+    pass
+
+
 def make_table(result_list: dict):
     if result_list["win_teamID"] == result_list["blue_teamID"]:
         team_blue_result = "胜利"
@@ -553,4 +607,4 @@ def make_table(result_list: dict):
                 </tbody>
             </table>
         </div>
-"""
\ No newline at end of file
+"""
